<?php


namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Contracts\Support\Renderable;

use App\Models\AgriculturalCalendar;
use Illuminate\Http\Request;
use Inertia\Inertia;
use App\Traits\UploadTrait;




class AgriculturalCalendarController extends Controller
{

     /**
      * Display a listing of the resource.
      * @return Renderable
      */
     use UploadTrait;
     // use agricultural_calendarservice;
     public function __construct()
     {
         $this->middleware('permission:agricultural_calendars-create', ['only' => ['create', 'store']]);
         $this->middleware('permission:agricultural_calendars-update',   ['only' => ['edit', 'update']]);
         $this->middleware('permission:agricultural_calendars-read',   ['only' => ['show', 'index']]);
         $this->middleware('permission:agricultural_calendars-delete',   ['only' => ['destroy']]);
         $this->middleware('permission:agricultural_calendars-eye',   ['only' => ['eye']]);
     }
     public function eye($id)
     {
         $active = AgriculturalCalendar::find($id);
         if ($active->active == 1) {
             $active->active = 0;
         } else {
             $active->active = 1;
         }
         $active->save();
         // return $active->active;
         return response()->json(["success" => true, "eye" => $active], 200);
     }
     public function index(Request $request)
     {
         $per_page = $request->itemsPerPage ?? 10;
         $orderBy = $request->sortBy ?? "id";
         $orderDir = $request->sortDesc ?? "desc";
         $agricultural_calendars = AgriculturalCalendar::orderBy($orderBy, $orderDir)
             ->filter($request->only('search'))
             ->paginate($per_page)
             ->appends(['search' => $request->only('search')]);
         if ($request->wantsJson()) {
             return $agricultural_calendars;
         }
         return Inertia::render("Admin/AgriculturalCalendar/Index", ["agricultural_calendars" => $agricultural_calendars]);
     }

     /**
      * Show the form for creating a new resource.
      * @return Renderable
      */
     public function create()
     {

         $calendar_tepyans =  AgriculturalCalendar::all();
         return Inertia::render("Admin/AgriculturalCalendar/Create", ["calendar_tepyans" => $calendar_tepyans]);
     }

     /**
      * Store a newly created resource in storage.
      * @param Request $request
      * @return Renderable
      */
     public function store(Request $request)
     {
     //     user_id
    //     name
//     title
//     details
//     starting_day
//     starting_month
//     end_day
  //end_month

         $request->validate([
             'name' => 'required',
             'title' => 'required',
             'details' => 'required',
             'starting_day' => 'required|integer',
             'starting_month' => 'required|integer',
             'end_day' => 'required|integer',
             'end_month' => 'required|integer',
         ]);
         $agricultural_calendars = new AgriculturalCalendar();
         $agricultural_calendars->user_id = auth()->user()->id;
         $agricultural_calendars->name = $request->name;
         $agricultural_calendars->title = $request->title;
         $agricultural_calendars->details = $request->details;
         $agricultural_calendars->starting_day = $request->starting_day;
         $agricultural_calendars->starting_month = $request->starting_month;
         $agricultural_calendars->end_day = $request->end_day;
         $agricultural_calendars->end_month = $request->end_month;

         $agricultural_calendars->save();
         return redirect()->route("agricultural_calendars.index")->with('success', 'تم اضافة  بنجاح');
     }
     /**
      * Show the specified resource.
      * @param int $id
      * @return Renderable
      */
     public function show($id)
     {
     }

     /**
      * Show the form for editing the specified resource.
      * @param int $id
      * @return Renderable
      */
     public function edit($id)
     {
         $agricultural_calendars =  AgriculturalCalendar::find($id);
         return Inertia::render("Admin/AgriculturalCalendar/Edit", ["agricultural_calendars" => $agricultural_calendars]);
     }

     /**
      * Update the specified resource in storage.
      * @param Request $request
      * @param int $id
      * @return Renderable
      */
     public function update(Request $request,$id)
     {
         $request->validate([
          //  'calendar_tipyans_id' => 'required|integer|unique:agricultural_calendars,calendar_tipyans_id,'. $id,
          'name' => 'required',
          'title' => 'required',
          'details' => 'required',
          'starting_day' => 'required|integer',
          'starting_month' => 'required|integer',
          'end_day' => 'required|integer',
          'end_month' => 'required|integer'
         ]);
         $agricultural_calendars =  AgriculturalCalendar::find($id);
         $agricultural_calendars->user_id = auth()->user()->id;
         $agricultural_calendars->name = $request->name;
         $agricultural_calendars->title = $request->title;
         $agricultural_calendars->details = $request->details;
         $agricultural_calendars->starting_day = $request->starting_day;
         $agricultural_calendars->starting_month = $request->starting_month;
         $agricultural_calendars->end_day = $request->end_day;
         $agricultural_calendars->end_month = $request->end_month;
         $agricultural_calendars->save();
         return redirect()->route("agricultural_calendars.index")->with('success', 'تم التعديل   بنجاح');
     }

     /**
      * Remove the specified resource from storage.
      * @param int $id
      * @return Renderable
      */
     public function destroy($id)
     {
         $agricultural_calendars = AgriculturalCalendar::find($id);
     //     $this->deleteImage($agricultural_calendars->image);
         $agricultural_calendars->delete();
         return true;
     }
 }
