<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\CalendarHijri;
use App\Models\CalendarTepyan;
use Illuminate\Http\Request;

use Inertia\Inertia;
use App\Traits\UploadTrait;
class CalendarHijriController extends Controller
{

    /**
     * Display a listing of the resource.
     * @return Renderable
     */
    use UploadTrait;
    // use calendar_hijriservice;
    public function __construct()
    {
        $this->middleware('permission:calendar_hijris-create', ['only' => ['create', 'store']]);
        $this->middleware('permission:calendar_hijris-update',   ['only' => ['edit', 'update']]);
        $this->middleware('permission:calendar_hijris-read',   ['only' => ['show', 'index']]);
        $this->middleware('permission:calendar_hijris-delete',   ['only' => ['destroy']]);
        $this->middleware('permission:calendar_hijris-eye',   ['only' => ['eye']]);
    }
    public function eye($id)
    {
        $active = CalendarHijri::find($id);
        if ($active->active == 1) {
            $active->active = 0;
        } else {
            $active->active = 1;
        }
        $active->save();
        // return $active->active;
        return response()->json(["success" => true, "eye" => $active], 200);
    }
    public function index(Request $request)
    {
        $per_page = $request->itemsPerPage ?? 10;
        $orderBy = $request->sortBy ?? "id";
        $orderDir = $request->sortDesc ?? "desc";
        $calendar_hijris = CalendarHijri::orderBy($orderBy, $orderDir)
            ->filter($request->only('search'))
            ->paginate($per_page)
            ->appends(['search' => $request->only('search')]);
        if ($request->wantsJson()) {
            return $calendar_hijris;
        }
        return Inertia::render("Admin/CalendarHijri/Index", ["calendar_hijris" => $calendar_hijris]);
    }

    /**
     * Show the form for creating a new resource.
     * @return Renderable
     */
    public function create()
    {

        $calendar_tepyans =  CalendarTepyan::all();
        return Inertia::render("Admin/CalendarHijri/Create", ["calendar_tepyans" => $calendar_tepyans]);
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Renderable
     */
    public function store(Request $request)
    {
    //     user_id
    // calendar_tipyans_id
    // day
    // month
    // year
    // yearm
        $request->validate([
            'calendar_tipyans_id' => 'required|string|unique:calendar_hijris,calendar_tipyans_id',
            'day' => 'required|integer',
            'month' => 'required|integer',
            'year' => 'required|integer',
            'yearm' => 'required|integer',
        ]);
        $calendar_hijris = new CalendarHijri();
        $calendar_hijris->user_id = auth()->user()->id;
        $calendar_hijris->calendar_tipyans_id = $request->calendar_tipyans_id;
        $calendar_hijris->day = $request->day;
        $calendar_hijris->month = $request->month;
        $calendar_hijris->year = $request->year;
        $calendar_hijris->yearm = $request->yearm;


        $calendar_hijris->save();
        return redirect()->route("calendar_hijris.index")->with('success', 'تم اضافة  بنجاح');
    }
    /**
     * Show the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function show($id)
    {
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function edit($id)
    {
        $calendar_hijris =  CalendarHijri::find($id);
        return Inertia::render("Admin/CalendarHijri/Edit", ["calendar_hijris" => $calendar_hijris]);
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Renderable
     */
    public function update(Request $request,$id)
    {
        $request->validate([
          'calendar_tipyans_id' => 'required|integer|unique:calendar_hijris,calendar_tipyans_id,'. $id,
          'day' => 'required|integer',
          'month' => 'required|integer',
          'year' => 'required|integer',
          'yearm' => 'required|integer',
        ]);
        $calendar_hijris =  CalendarHijri::find($id);
        $calendar_hijris->user_id = auth()->user()->id;
        $calendar_hijris->calendar_tipyans_id = $request->calendar_tipyans_id;
        $calendar_hijris->day = $request->day;
        $calendar_hijris->month = $request->month;
        $calendar_hijris->year = $request->year;
        $calendar_hijris->yearm = $request->yearm;
        $calendar_hijris->save();
        return redirect()->route("calendar_hijris.index")->with('success', 'تم التعديل   بنجاح');
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Renderable
     */
    public function destroy($id)
    {
        $calendar_hijris = CalendarHijri::find($id);
        $this->deleteImage($calendar_hijris->image);
        $calendar_hijris->delete();
        return true;
    }
}
